<?php

namespace Drupal\rules_webform\Plugin\RulesAction;

use Drupal\rules\Core\RulesActionBase;

/**
 * Action for altering of webform submission value.
 *
 * @RulesAction(
 *   id = "set_webform_field_value",
 *   label = @Translation("Set webform field value"),
 *   category = @Translation("A Webform"),
 *   context = {
 *     "field" = @ContextDefinition("any",
 *       label = @Translation("Webform field"),
 *       required = TRUE,
 *       assignment_restriction = "selector"
 *     ),
 *     "value" = @ContextDefinition("any",
 *       label = @Translation("Value"),
 *       required = TRUE
 *     )
 *   }
 * )
 */
class SetWebformFieldValue extends RulesActionBase {

  /**
   * Set a webform field value.
   *
   * @param mixed $field
   *   A webform field.
   * @param mixed $value
   *   New value of a webform field.
   */
  protected function doExecute($field, $value) {
    $submission = \Drupal::state()->get('rules_webform.submission');
    // Do nothing if a submission has been removed by 'delete_webform_submission' action.
    if (!isset($submission)) {
      return;
    }

    $data = $submission->getData();

    $field_name = $this
      ->getContexts()['field']
      ->getContextData()
      ->getName();

    if (array_key_exists($field_name, $data)) {
      $data[$field_name] = $value;
      $submission->setData($data);
      $submission->save();
    }
  }

}
